@@ -202,7 +202,7 @@ def test_logging_duplicate_ids(
             c.upload()
 
         assert str(e.value).startswith(
-            "It seems as though you do not have unique ids in split training"
+            "It seems your logged output data has duplicate ids"
         )
     finally:
         # Mock finish() call without calling the API
@@ -694,3 +694,60 @@ def test_log_assertion_error_raises(
         logger._log()
     mock_get_data.assert_not_called()
     mock_write.assert_not_called()
+
+
+@mock.patch("dataquality.loggers.data_logger.base_data_logger.is_galileo_cloud")
+def test_validate_data_size_cloud(mock_cloud: MagicMock) -> None:
+    mock_cloud.return_value = True
+    df = vaex.from_arrays(
+        id=list(range(BaseGalileoDataLogger.MAX_DATA_SIZE_CLOUD + 1)),
+        label=["a" for _ in range(BaseGalileoDataLogger.MAX_DATA_SIZE_CLOUD + 1)],
+        text=["text" for _ in range(BaseGalileoDataLogger.MAX_DATA_SIZE_CLOUD + 1)],
+    )
+    with pytest.warns(GalileoWarning):
+        BaseGalileoDataLogger().validate_data_size(df)
+
+
+@mock.patch("dataquality.loggers.data_logger.base_data_logger.is_galileo_cloud")
+def test_validate_under_data_size_cloud(mock_cloud: MagicMock) -> None:
+    mock_cloud.return_value = True
+    df = vaex.from_arrays(
+        id=list(range(BaseGalileoDataLogger.MAX_DATA_SIZE_CLOUD)),
+        label=["a" for _ in range(BaseGalileoDataLogger.MAX_DATA_SIZE_CLOUD)],
+        text=["text" for _ in range(BaseGalileoDataLogger.MAX_DATA_SIZE_CLOUD)],
+    )
+    with pytest.warns(None):
+        BaseGalileoDataLogger().validate_data_size(df)
+
+
+@mock.patch("dataquality.loggers.data_logger.base_data_logger.is_galileo_cloud")
+def test_validate_data_size_not_cloud(mock_cloud: MagicMock) -> None:
+    mock_cloud.return_value = False
+    df = vaex.from_arrays(
+        id=list(range(BaseGalileoDataLogger.MAX_DATA_SIZE_CLOUD + 1)),
+        label=["a" for _ in range(BaseGalileoDataLogger.MAX_DATA_SIZE_CLOUD + 1)],
+        text=["text" for _ in range(BaseGalileoDataLogger.MAX_DATA_SIZE_CLOUD + 1)],
+    )
+    with pytest.warns(None):
+        BaseGalileoDataLogger().validate_data_size(df)
+
+
+@mock.patch(
+    "dataquality.loggers.base_logger.is_galileo_cloud",
+    return_value=True,
+)
+def test_cloud_restricts_inference_mode(mock_cloud: MagicMock) -> None:
+    text_inputs = ["sample1", "sample2", "sample3"] * 30
+    ids = list(range(90))
+
+    dq.set_labels_for_run(["A", "B", "C"])
+    with pytest.raises(GalileoException) as e:
+        dq.log_data_samples(
+            texts=text_inputs, split="inference", ids=ids, inference_name="test"
+        )
+
+    assert str(e.value) == (
+        "You cannot log inference data from a Galileo Cloud account, only enterprise "
+        "accounts can access this feature. Please email us at team@rungalileo.io for "
+        "more information."
+    )
